@@ -15,6 +15,7 @@ class Write(Action[Name, int]):
         prefix: Optional[str] = None,
         overwrite: bool = False,
         append: bool = False,
+        mkdir: bool = False,
     ):
         acceptable_prefix_types = [bytes, str]
         prefix_type, to_write_type = type(prefix), type(to_write)
@@ -35,6 +36,7 @@ class Write(Action[Name, int]):
         self.prefix = prefix
         self.append = append
         self.overwrite = overwrite
+        self.mkdir = mkdir
         self.area = None
         self.path = None
 
@@ -58,6 +60,9 @@ class Write(Action[Name, int]):
         else:
             raise TypeError(f'Must be of str or bytes: {self.to_write}')
 
+        if self.mkdir and not self.path.is_dir():
+            self.path.resolve().parent.mkdir(parents=True, exist_ok=True)
+
         if self.append:
             rchar = b'\n' if mode == 'ab' else '\n'
             self.path.open(mode).write(msg + rchar)
@@ -68,10 +73,10 @@ class Write(Action[Name, int]):
     def validate(self) -> Write[Name, int]:
         if self.overwrite and self.append:
             raise ValueError('Cannot overwrite and append simultaneously')
-        if self.path and self.path.exists() and not self.overwrite and not self.append:
-            raise FileExistsError(f'Cannot {str(self)} to {str(self.path)}')
         if self.path and self.path.is_dir():
             raise IsADirectoryError(str(self.path))
+        if self.path and self.path.exists() and not self.overwrite and not self.append:
+            raise FileExistsError(f'Cannot {str(self)} to {str(self.path)}')
         return self
 
     class STDOUT:
