@@ -20,7 +20,6 @@ EXAMPLE = envvar.get('EXAMPLE', 'actionpack')
 
 external = False if USEVENV else True
 supported_python_versions = [
-    '3.6',
     '3.7',
     '3.8',
     '3.9',
@@ -93,7 +92,8 @@ def test(session):
     if COVERAGE:
         session.run(
             'python', '-m',
-            'coverage', 'run', '--source', f'{TESTDIR}', '--branch',
+            'coverage', 'run', '--source', '.', '--branch',
+            '--omit', '**tests/*,**/__*__.py,noxfile.py,setup.py',
             '-m', 'unittest', TESTNAME if TESTNAME else f'discover',
             external=external
         )
@@ -110,4 +110,3 @@ def test(session):
 @nox.session(name=session_name('build'), python=supported_python_versions)
 def build(session):
     session.run('python', 'setup.py', 'sdist')
-
