@@ -183,6 +183,29 @@ class ResultTest(TestCase):
         with self.assertRaises(Result.OutcomeMustBeOfTypeEither):
             Result('not an Either type')
 
+    def test_cannot_change_immutable_attributes(self):
+        result = Result(Right('correct.'))
+        with self.assertRaises(AttributeError):
+            result.produced_at = 123
+        with self.assertRaises(AttributeError):
+            result.successful = False
+        with self.assertRaises(AttributeError):
+            result.value = 'some other value'
+
+        result.who_cares = 'right?'  # should not raise since not declared immutable
+
+    def test_cannot_delete_immutable_attributes(self):
+        result = Result(Right('correct.'))
+        with self.assertRaises(AttributeError):
+            del result.produced_at
+        with self.assertRaises(AttributeError):
+            del result.successful
+        with self.assertRaises(AttributeError):
+            del result.value
+
+        result.who_cares = 'right?'
+        del result.who_cares  # should not raise since not declared immutable
+
     def test_can_serialize_result(self):
         successful_outcome = 'correct.'
         successful_result = Result(Right(successful_outcome))
@@ -195,9 +218,3 @@ class ResultTest(TestCase):
         confused_result = Result(Left(successful_outcome))
         self.assertFalse(confused_result.successful)
 
-    def test_Result_successful_attribute_is_immutable(self):
-        result = Result(Right('correct.'))
-        with self.assertRaises(AttributeError):
-            del result.successful
-        result.who_cares = 'right?'
-        del result.who_cares  # should not raise since not declared immutable
